Hello from pygamer.{the creator of this module}

#-- project discription--
    it's an simple project that can help you create awsome gui.
#-------------------------

#-- contains --
    Two files -
               |
               V
        1) window.py
        2) tools.py
description obout files is contained within them as comment
#-------------------

consider supporting by suscribing my channel on youtube:->https://www.youtube.com/channel/UCNj9jZBVxRWm7TA5g2K7XtA

